Heros Devices 0.11.1 documentation

Skip to content
Back to top
View this page

# HEROS Devices

Heros Devices is a place for specific device driver representations that work best with HEROS and the starter BOSS.

## Documentation of the ecosystem

BOSS | Starter to initialize HEROs
HERO Monitor | Simple GUI to manage HEROs
HERO Tools | Tools for HEROS like data aggregators and storage clients
Atomiq | Feature-rich convenience layer and HEROS integration for ARTIQ
HEROS | Communication/bus backend

## Getting Started with HEROS Devices

- Getting Started
  - Starting a device HERO
  - Adding vendor libraries
- Tutorials
  - Building a Custom Arduino Driver for DHT11 Sensors

## Hardware

- Hardware

## API Reference

- API Reference
  - herosdevices
    - Submodules
      - herosdevices.core
        - Submodules
          - herosdevices.core.bus
          - herosdevices.core.gpio
          - herosdevices.core.templates
        - Package Contents
          - `FieldType`
          - `any__new__()`
          - `DeviceCommandQuantity`
          - `SubQuantity`
      - herosdevices.hardware
        - Submodules
          - herosdevices.hardware.Ftdi
          - herosdevices.hardware.analog_devices
          - herosdevices.hardware.dummy
          - herosdevices.hardware.ftdi
          - herosdevices.hardware.gamma_vacuum
          - herosdevices.hardware.hamamatsu
          - herosdevices.hardware.highfinesse
          - herosdevices.hardware.ids
          - herosdevices.hardware.megatec
          - herosdevices.hardware.newport
          - herosdevices.hardware.picotechnology
          - herosdevices.hardware.raspberrypi
          - herosdevices.hardware.rigol
          - herosdevices.hardware.rohde_schwarz
          - herosdevices.hardware.saes
          - herosdevices.hardware.santec
          - herosdevices.hardware.sinara
          - herosdevices.hardware.srs
          - herosdevices.hardware.teledyne
          - herosdevices.hardware.texas_instruments
          - herosdevices.hardware.thorlabs
          - herosdevices.hardware.toptica
          - herosdevices.hardware.windfreak
      - herosdevices.helper
        - Module Contents
          - `SPAM`
          - `Logger`
          - `format_str`
          - `log`
          - `SI_PREFIX_EXP`
          - `limits()`
          - `limits_int()`
          - `explicit()`
          - `extract_regex()`
          - `sanitize_member_name()`
          - `transform_unit()`
          - `merge_dicts()`
          - `get_or_create_dynamic_subclass()`
          - `add_class_descriptor()`
          - `mark_driver()`
          - `cast_iterable()`
          - `make_identifier()`
      - herosdevices.interfaces
        - Submodules
          - herosdevices.interfaces.atomiq
          - herosdevices.interfaces.heros
        - Package Contents
          - `Interface`
          - `UnionInterfaceMeta`

## Contributing

- Contributing
  - Ways to Contribute
  - Making Changes to the Codebase
  - Working with branches
  - Coding Guidelines
  - Writing documentation

# Indices and tables

- Index

- Module Index

- Search Page